package main

import (
	"fmt"
	"html"
	"io/ioutil"
	"log"
	"net/http"

	"gopkg.in/yaml.v3"
)

type ServerConfig struct {
	Name     string
	Homepage string
}
type AdminConfig struct {
	WebRoot string
}
type AuthConfig struct {
	GiteaURL        string
	AuthorizedUsers []string
}
type Config struct {
	Server ServerConfig
	Admin  AdminConfig
	Auth   AuthConfig
}

var config = new(Config)

func loadConfig() (err error) {
	configfile, err := ioutil.ReadFile("config.yml")
	if err != nil {
		return err
	}

	err = yaml.Unmarshal(configfile, &config)
	return err
}

func main() {
	err := loadConfig()
	if err != nil {
		log.Fatal("oh no !!!")
	}

	http.HandleFunc("/", func(w http.ResponseWriter, r *http.Request) {
		fmt.Fprintf(w, "Hello, %q", html.EscapeString(r.URL.Path))
	})

	err = http.ListenAndServe(":8080", nil)
	if err != nil {
		log.Fatal(err)
	}

}
